@@ -111,7 +111,9 @@ NO = "No"
 CREATE_PROJECT_COMMAND = "neuralspace nlu create-project --help"
 UPLOAD_DATASET_COMMAND = "neuralspace nlu upload-dataset --help"
 INSTALL_APP_COMMAND = "neuralspace install-app --help"
-
+TRAIN_MODEL_COMMAND = "neuralspace nlu train --help"
+DEPLOY_MODEL_COMMAND = "neuralspace nlu deploy --help"
+PARSE_MODEL_COMMAND = "neuralspace nlu parse --help"
 # checking command
 
 APP_IS_INSTALLED = "App is already installed"
