@@ -14,8 +14,10 @@ from neuralspace.constants import (
     COMMON_HEADERS,
     COMPLETED,
     COUNT,
+    CREATE_PROJECT_COMMAND,
     DATA,
     DEAD,
+    DEPLOY_MODEL_COMMAND,
     END_INDEX,
     ENTITIES,
     ENTITY_ACC,
@@ -43,6 +45,7 @@ from neuralspace.constants import (
     NUMBER_OF_MODELS,
     PAGE_NUMBER,
     PAGE_SIZE,
+    PARSE_MODEL_COMMAND,
     PREPARED,
     PROJECT_ID,
     PROJECT_NAME,
@@ -53,6 +56,7 @@ from neuralspace.constants import (
     START_INDEX,
     TEXT,
     TIMED_OUT,
+    TRAIN_MODEL_COMMAND,
     TRAINING,
     TRAINING_STATUS,
     TRAINING_TIME,
@@ -102,6 +106,9 @@ async def get_languages() -> Dict[Text, Any]:
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully created project"
             )
             console.print(f"{json.dumps(json_response, indent=4)}")
+            console.print(
+                f"⏩ To create the project: [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to create project")
             console.print(
@@ -184,6 +191,9 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
             console.print(
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project"
             )
+            console.print(
+                f"⏩ To create the project:  [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete projects")
             console.print(
@@ -237,7 +247,9 @@ async def list_projects(
                 f"with Page Size: {page_size}"
             )
             print_projects_table(json_response, verbose)
-            console.print(f"⏩ To upload your dataset: {UPLOAD_DATASET_COMMAND}")
+            console.print(
+                f"⏩ To upload your dataset: [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list projects")
             console.print(
@@ -306,11 +318,20 @@ async def list_examples(
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             print_examples_table(json_response, verbose)
+            console.print(
+                f"⏩ To train the model: [dark_orange3]{TRAIN_MODEL_COMMAND}[/dark_orange3]"
+            )
+            console.print(
+                "[red]📝NOTE: To train a model in a project, the project must have minimum"
+                " [orange4]2[/orange4] intent and every intent must atleast have[/red] "
+                "[orange4]10[/orange4] [red]training examples[/red]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list examples")
             console.print(
                 f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
+
     return json_response
 
 
@@ -403,6 +424,9 @@ async def list_models(
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             print_models_table(json_response, verbose)
+            console.print(
+                f"⏩ To deploy the model: [orange4]{DEPLOY_MODEL_COMMAND}[/dark_orange3]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list models")
             console.print(
@@ -492,6 +516,7 @@ async def upload_dataset(
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ❌ Failed on {len(error_examples)} examples"
     )
+    console.print(f"To train your model: {TRAIN_MODEL_COMMAND}")
     with open("failed_examples.json", "w") as f:
         json.dump(error_examples, f, ensure_ascii=False)
         console.print(
@@ -531,6 +556,11 @@ async def wait_till_training_completes(
                             or json_response[DATA][TRAINING_STATUS] == TIMED_OUT
                             or json_response[DATA][TRAINING_STATUS] == DEAD
                         ):
+                            if json_response[DATA][TRAINING_STATUS] == COMPLETED:
+                                console.print(
+                                    f"⏩ To deploy your model on Neuralspace platform: "
+                                    f"[orange4]{DEPLOY_MODEL_COMMAND}[/dark_orange3]"
+                                )
                             break
                     else:
                         console.print(
@@ -606,6 +636,9 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
             console.print(
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted model"
             )
+            console.print(
+                f"⏩ To upload the dataset: [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete models")
             console.print(
@@ -633,7 +666,7 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully"
             )
             console.print(
-                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}"
+                f"⏩ To parse the model: [dark_orange3]{PARSE_MODEL_COMMAND}[/dark_orange3]"
             )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to deploy model")
