@@ -116,11 +116,18 @@ async def app_install(name: Text):
             console.print(
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Install Successful!"
             )
+            console.print(
+                f"⏩ To use the {name} app: [dark_orange3]neuralspace {name}[dark_orange3] --help"
+            )
         else:
             if json_response["message"] == APP_IS_INSTALLED:
                 console.print(
-                    f"> [deep_sky_blue2]INFO[/deep_sky_blue2] [dark_orange3]{APP_IS_INSTALLED}[/dark_orange3]"
+                    f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅  {APP_IS_INSTALLED}"
                 )
+                console.print(
+                    f"⏩ To use the {name} app: [dark_orange3]neuralspace {name}[dark_orange3] --help"
+                )
+
             else:
                 console.print("> [red]ERROR[/red] ❌ Install Failed!")
                 console.print(
